@@ -7,6 +7,9 @@ class ApiSettings(ApiBase):
     def cloud_providers(self):
         return self.build_route("settings/cloudproviders")
 
+    def aws_cloud_providers(self):
+        return self.build_route("settings/cloudproviders/aws")
+
     def cloud_accounts(self):
         return self.build_route("settings/cloudaccounts")
 
