@@ -17,7 +17,7 @@ from gateways.common.cs18_api_requests import (
     CreateInvitationsRequest,
     UpdateSpaceRequest,
     ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest,
-    AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest)
+    AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest, AwsCloudProviderSettingsModel)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -28,7 +28,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 UserForAllUsersResponse, CloudAccountInSpaceResponse, RegionResponse,
                                                 VerifyCloudProviderResponse, AccountRepositoryResponse,
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
-                                                DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse)
+                                                DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
+                                                ParameterStoreItem)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -838,6 +839,12 @@ class Colony:
         GatewayUtils.handle_response(response=res, return_codes=[200])
         return [Converters.get_image_response(x) for x in json.loads(res.text)]
 
+    def get_instance_types(self, space_name: str, cloud_account_name: str, region_id: str):
+        url = self._api_root.spaces.get_instance_types(space_name, cloud_account_name, region_id)
+        res = self.session.get(url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        return [Converters.get_instance_type_response(x) for x in json.loads(res.text)]
+
     def update_space(self, space: str, update_space_request: UpdateSpaceRequest):
         url = self._api_root.spaces.space_by_name(space_name=space)
         response = self.session.put(url=url, json=update_space_request.__dict__)
@@ -1168,6 +1175,44 @@ class Colony:
         response_json = json.loads(response.text)
         return Converters.create_direct_rdp_response(response_json)
 
+    def add_parameter_store(self, parameter: ParameterStoreItem):
+        method_url = self._api_root.parameterStore.parameters()
+        response = self.session.post(url=method_url, json=Utils.get_as_json(parameter))
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def get_all_parameters(self):
+        method_url = self._api_root.parameterStore.parameters()
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200, 204])
+        response_json = json.loads(response.text)
+        return Converters.create_get_all_parameters_response(response_json)
+
+    def get_parameter(self, parameter_name: str):
+        method_url = self._api_root.parameterStore.parameter(parameter_name=parameter_name)
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200, 204])
+        response_json = json.loads(response.text)
+        return Converters.create_get_parameter_response(response_json)
+
+    def delete_parameter(self, parameter_name: str):
+        method_url = self._api_root.parameterStore.parameter(parameter_name=parameter_name)
+        response = self.session.delete(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def set_aws_cloud_provider_settings(self, model: AwsCloudProviderSettingsModel):
+        method_url = self._api_root.settings.aws_cloud_providers()
+
+        response = self.session.put(url=method_url, json=model.__dict__)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+
+    def get_aws_cloud_provider_settings(self) -> AwsCloudProviderSettingsModel:
+        method_url = self._api_root.settings.aws_cloud_providers()
+
+        response = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=response, return_codes=[200])
+        response_json = json.loads(response.text)
+        return Converters.aws_cloud_provider_settings_model(data=response_json)
+
 
 class SandboxesHandler:
     def __init__(self):
