@@ -3,6 +3,7 @@ from datetime import datetime
 import dateutil.parser
 from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
+from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
 from gateways.common.cs18_api_responses import (
     SpaceAdmin,
     SpaceCloudAccount,
@@ -43,12 +44,13 @@ from gateways.common.cs18_api_responses import (
     BlueprintServiceResponse,
     LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
     CloudAccountInfraSetResponse, CloudAccountSubnetsResponse, RegionResponse, GetImagesResponse,
-    VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse, AccountRepositoryResponse,
-    BlueprintValidationResponse, BlueprintSourceResponse, CloudAccountCostResponse,
+    GetInstanceTypesResponse, VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse,
+    AccountRepositoryResponse, BlueprintValidationResponse, BlueprintSourceResponse, CloudAccountCostResponse,
     ComputeServiceInAccountResponse, ComputeServiceInSpaceResponse, ComputeServiceSpaceSpecResponse,
     K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse,
     AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
-    SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse)
+    SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse, ParameterStoreItem,
+    ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue)
 
 
 class Converters:
@@ -871,6 +873,10 @@ class Converters:
     def get_image_response(images: dict):
         return GetImagesResponse(images['image_id'], images['image_name'])
 
+    @staticmethod
+    def get_instance_type_response(instance_types: dict):
+        return GetInstanceTypesResponse(instance_types['instance_type_name'])
+
     @staticmethod
     def _create_resources_summary_response(resources_summary: dict) -> List[VerifyCloudProviderResourceResponse]:
         resources = []
@@ -950,3 +956,43 @@ class Converters:
             rdp_file_url=data["rdp_file_url"],
             username=data["username"],
             password=data["password"])
+
+    @staticmethod
+    def create_parameter_value_response(origin: str, raw_parameter_value: dict) -> ParameterStoreValue:
+        if origin == ParameterStoreOrigin.Literal:
+            return LiteralValue(content=raw_parameter_value["content"])
+        if origin == ParameterStoreOrigin.AwsSsm:
+            return AwsSsmValue(path=raw_parameter_value["path"])
+
+        return None
+
+    @staticmethod
+    def create_get_all_parameters_response(data: dict) -> List[ParameterStoreItem]:
+        parameters = []
+        if data:
+            for parameter in data:
+                parameters.append(
+                    ParameterStoreItem(
+                        name=parameter["name"],
+                        origin=parameter["origin"],
+                        value=Converters.create_parameter_value_response(parameter["origin"], parameter["value"]),
+                        description=parameter["description"])
+                )
+        return parameters
+
+    @staticmethod
+    def create_get_parameter_response(data: dict) -> Optional[ParameterStoreItem]:
+        parameter = None
+        if data:
+            parameter = ParameterStoreItem(
+                name=data["name"],
+                origin=data["origin"],
+                value=Converters.create_parameter_value_response(data["origin"], data["value"]),
+                description=data["description"])
+        return parameter
+
+    @staticmethod
+    def aws_cloud_provider_settings_model(data: dict) -> AwsCloudProviderSettingsModel:
+        return AwsCloudProviderSettingsModel(
+            sidecar_image_param_name=data.get("sidecar_image_param_name", None)
+        )
