@@ -2,7 +2,7 @@
 Container for Request object used in cs18-api-client
 """
 from enum import Enum
-from typing import List
+from typing import List, Optional
 
 
 class ProductionEnvironment(Enum):
@@ -102,3 +102,8 @@ class UpdateK8SComputeServiceInSpaceRequest:
     def __init__(self, namespace: str, internet_facing: bool) -> None:
         self.namespace = namespace
         self.internet_facing = internet_facing
+
+
+class AwsCloudProviderSettingsModel:
+    def __init__(self, sidecar_image_param_name: Optional[str]):
+        self.sidecar_image_param_name = sidecar_image_param_name
