@@ -5,6 +5,7 @@ Container for Response objects used in cs18-api-client
 import abc
 
 from datetime import datetime
+from enum import Enum
 from typing import List, Dict, Optional
 
 from gateways.common.cs18_api_classes import AccessLink
@@ -941,6 +942,11 @@ class GetImagesResponse:
         self.image_name = image_name
 
 
+class GetInstanceTypesResponse:
+    def __init__(self, instance_type_name: str):
+        self.instance_type_name = instance_type_name
+
+
 class VerifyCloudProviderResourceResponse:
     def __init__(self,
                  resource_type: str,
@@ -1045,3 +1051,33 @@ class DirectRdpResponse:
         self.rdp_file_url = rdp_file_url
         self.username = username
         self.password = password
+
+
+class ParameterStoreOrigin(str, Enum):
+    Literal = 'literal'
+    AwsSsm = 'aws-ssm'
+
+
+class ParameterStoreValue(metaclass=abc.ABCMeta):
+    def __init__(self):
+        pass
+
+
+class LiteralValue(ParameterStoreValue):
+    def __init__(self, content: str):
+        super().__init__()
+        self.content = content
+
+
+class AwsSsmValue(ParameterStoreValue):
+    def __init__(self, path: str):
+        super().__init__()
+        self.path = path
+
+
+class ParameterStoreItem:
+    def __init__(self, name: str, origin: str, value: ParameterStoreValue, description: str = ''):
+        self.name = name
+        self.origin = origin
+        self.description = description
+        self.value = value
