@@ -307,6 +307,11 @@ class Utils:
                 return dirpath
         return "{} was not found".format(file)
 
+    @staticmethod
+    def get_as_json(my_object) -> dict:
+        object_as_json_str = json.dumps(my_object, default=lambda o: o.__dict__)
+        return json.loads(object_as_json_str)
+
 
 class GatewayUtils:
     """
